summaryrefslogtreecommitdiffstats
path: root/config
diff options
context:
space:
mode:
Diffstat (limited to 'config')
-rw-r--r--config/environment.rb4
1 files changed, 2 insertions, 2 deletions
diff --git a/config/environment.rb b/config/environment.rb
index 8ff43e0ac..e5e7d0e4b 100644
--- a/config/environment.rb
+++ b/config/environment.rb
@@ -13,8 +13,8 @@ Rails::Initializer.run do |config|
# Skip frameworks you're not going to use
# config.frameworks -= [ :action_web_service, :action_mailer ]
- # Add additional load paths for your own custom dirs
- # config.load_paths += %W( #{RAILS_ROOT}/extras )
+ # Add additional load paths for sweepers
+ config.load_paths += %W( #{RAILS_ROOT}/app/sweepers )
# Force all environments to use the same logger level
# (by default production uses :info, the others :debug)